==> foundation-design-system-1.0.1.tgz: package/README.md <==
# Foundation Design System
Foundation Design System is a collection of design tokens, components and guidelines for building cohesive UI systems within parts of [Envato](https://envato.com).

This project is based off of Salesforce's [theo](https://github.com/salesforce-ux/theo).

***

**Status:** Work in Progress.

***
### Developer Setup

Clone the repository:
```sh
git clone git@github.com:envato/foundation-design-system.git
```
Install dependencies:
```sh
$ npm i
```
Watch (and automatically build):
```sh
$ gulp watch
```

Notes for developing style guide sites:

The custom css for the style guide is located at `sites/app/app.scss` and will be build into `sites/app/app.css`, we use this file to apply custom style on style guide.

### Usage

```sh
$ npm install @envato-foundation/foundation-design-system --save
```

#### Webpack and scss-loader example

Config loaders in `webpack.config.js`

```js
module: {
  loaders: [
    {
      test: /\.scss$/,
      loader: ExtractTextPlugin.extract('style-loader', 'css-loader', 'sass-loader')
    }
  ]
},
plugins: [
  new ExtractTextPlugin('[name].css')
],
resolve: {
  extensions: ['', '.js', '.scss'],
  root: [path.join(__dirname, './node_modules')]
}
```

And then in your code

```js
require('@envato-foundation/foundation-design-system/dist/colors.scss')
```

For a complete example please check the `example` directory.

### Deploying Design System Demo Sites

```sh
$ npm run deploy
```

### Publishing to npm

* Bump the version in `package.json` (make sure you follow [semantic versioning rules](https://docs.npmjs.com/getting-started/semantic-versioning))
* Run `npm publish`


### Guide for creating Design Tokens
Design tokens are essential particles of a design system, specifically, they are variables that store visual design attributes. They can contain colors (hex, RGBA or other values), sizing units (pixels, rems, etc.) and many more. They're essential for creating and maintaing a consistent visual system.

```yml
  # global is required
  global:
    # category has to be defined at the top of each file
    category: "app"
  # use `imports` to import other files
  imports:
    [
      "./colors.yml",
      "./fonts.yml"
    ]
  # props is required to write `key` and `value` pairs
  props:
    font-size--body-m:
      value: "16px"
      # type is not used in the generated result but is required by the plugin
      # helps to categorize
      type: "font-size"
```

| Name | Description | Required |
| --- | --- | --- |
| global | meta information can be put here, will have other sub attribute | True |
| category | category attribute, can be `color`, `font` or whatever, required but not used in the output | True |
| imports | import other files | False |
| props | define your key value pair | True |
| type | type of the attribute, not used in the output but required | True |

### Maintainers
* [Fraser Xu](https://github.com/fraserxu)
* [István Huszár](https://github.com/khayman)
* [Jordan Lewis](https://github.com/jordanlewiz)
* [Karolina Szczur](https://github.com/thefoxis)
* [Paweł Gałązka](https://github.com/pawelgalazka)

### Code of Conduct
This project adheres to the Contributor Covenant [Code Of Conduct](CODE_OF_CONDUCT.md). By participating, you are expected to uphold this code. Please report unacceptable behavior to [market-foundation-dev@envato.com](mailto:market-foundation-dev@envato.com).

### License
[MIT](LICENSE)

==> foundation-design-system-1.1.0.tgz: package/README.md <==
# Foundation Design System
Foundation Design System is a collection of design tokens, components and guidelines for building cohesive UI systems within parts of [Envato](https://envato.com).

This project is based off of Salesforce's [theo](https://github.com/salesforce-ux/theo).

***

**Status:** Work in Progress.

***

### Developer Setup

Clone the repository:
```sh
git clone git@github.com:envato/foundation-design-system.git
```
Install dependencies:
```sh
$ npm i
```
Watch (and automatically build):
```sh
$ gulp watch
```

Notes for developing style guide sites:

The custom css for the style guide is located at `sites/app/app.scss` and will be build into `sites/app/app.css`, we use this file to apply custom style on style guide.

### Deploying Design System Demo Sites

```sh
$ npm run deploy
```

### Publishing a new version

* Bump the version in `package.json` (make sure you follow [semantic versioning rules](https://docs.npmjs.com/getting-started/semantic-versioning)):
```sh
$ npm version major|minor|patch
```
* Follow [the instructions for Changelog writing](http://keepachangelog.com/en/0.3.0/) and describe the changes in [CHANGELOG.md](CHANGELOG.md)
* Create a corresponding [release notes](https://github.com/envato/foundation-design-system/releases) (same as `CHANGELOG.md`):
* Publish to npm
```sh
npm publish
```

:tada:

### Usage
Find complete usage instructions in [How to Use page](HOW_TO_USE.md).

### Guide for creating Design Tokens
Read about creating Design Tokens [here](CREATING_DESIGN_TOKENS.md).

### Maintainers
* [Fraser Xu](https://github.com/fraserxu)
* [István Huszár](https://github.com/khayman)
* [Jordan Lewis](https://github.com/jordanlewiz)
* [Karolina Szczur](https://github.com/thefoxis)
* [Paweł Gałązka](https://github.com/pawelgalazka)

### Code of Conduct
This project adheres to the Contributor Covenant [Code Of Conduct](CODE_OF_CONDUCT.md). By participating, you are expected to uphold this code. Please report unacceptable behavior to [market-foundation-dev@envato.com](mailto:market-foundation-dev@envato.com).

### License
[MIT](LICENSE)
